Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4480)

Unified Diff: chrome/renderer/content_settings_observer_browsertest.cc

Issue 2799093002: s/DidNavigateWithinPage/OnSameDocumentNavigation. (Closed)
Patch Set: Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/renderer/safe_browsing/phishing_classifier_delegate_browsertest.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/renderer/content_settings_observer_browsertest.cc
diff --git a/chrome/renderer/content_settings_observer_browsertest.cc b/chrome/renderer/content_settings_observer_browsertest.cc
index bd2e722c32a6e6c146a72359efb5473808eb6a4b..77b6de443ab1695cf23a43d3c532d7b89f6efa66 100644
--- a/chrome/renderer/content_settings_observer_browsertest.cc
+++ b/chrome/renderer/content_settings_observer_browsertest.cc
@@ -156,8 +156,8 @@ TEST_F(ChromeRenderViewTest, PluginsTemporarilyAllowed) {
EXPECT_TRUE(observer->IsPluginTemporarilyAllowed(foo_plugin));
EXPECT_FALSE(observer->IsPluginTemporarilyAllowed(bar_plugin));
- // Simulate a navigation within the page.
- DidNavigateWithinPage(GetMainFrame(), true, true);
+ // Simulate same document navigation.
+ OnSameDocumentNavigation(GetMainFrame(), true, true);
EXPECT_TRUE(observer->IsPluginTemporarilyAllowed(foo_plugin));
EXPECT_FALSE(observer->IsPluginTemporarilyAllowed(bar_plugin));
@@ -426,8 +426,8 @@ TEST_F(ChromeRenderViewTest, ContentSettingsSamePageNavigation) {
observer->SetContentSettingRules(&content_setting_rules);
// The page shouldn't see the change to script blocking setting after a
- // same page navigation.
- DidNavigateWithinPage(GetMainFrame(), true, true);
+ // same document navigation.
+ OnSameDocumentNavigation(GetMainFrame(), true, true);
EXPECT_TRUE(observer->allowScript(true));
}
« no previous file with comments | « no previous file | chrome/renderer/safe_browsing/phishing_classifier_delegate_browsertest.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698